my $d = 'efg';

{   d        => $d,
    hostname => $properties{hostname},
    username => $Config::Entities::properties->{username},
    password => $properties{password}
}
